summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorAlan Tull <alan.tull@freescale.com>2011-06-28 11:18:05 -0500
committerAlan Tull <alan.tull@freescale.com>2011-10-25 11:51:19 -0500
commit05833498aa87b1e5ae7f577f2181bcfb00f2964c (patch)
tree0941b2e3dbb7c6ab44de77bc73ece98886da8413 /include
parent9687c1de73d069054badc28c0f73e5bfe20ab04b (diff)
ENGR00139265-2 mxc alsa soc spdif driver
* Add spdif block clock divider settings and spdif_clk_set_rate function to mxc_spdif_platform_data. Signed-off-by: Alan Tull <alan.tull@freescale.com>
Diffstat (limited to 'include')
-rw-r--r--include/linux/fsl_devices.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/include/linux/fsl_devices.h b/include/linux/fsl_devices.h
index 4f9e869a4fae..0f75c656f005 100644
--- a/include/linux/fsl_devices.h
+++ b/include/linux/fsl_devices.h
@@ -325,7 +325,11 @@ struct mxc_spdif_platform_data {
int spdif_rx; /* S/PDIF rx enabled for this board */
int spdif_clk_44100; /* tx clk mux in SPDIF_REG_STC; -1 for none */
int spdif_clk_48000; /* tx clk mux in SPDIF_REG_STC; -1 for none */
- int spdif_clkid; /* rx clk mux select in SPDIF_REG_SRPC */
+ int spdif_div_44100; /* tx clk div in SPDIF_REG_STC */
+ int spdif_div_48000; /* tx clk div in SPDIF_REG_STC */
+ int spdif_div_32000; /* tx clk div in SPDIF_REG_STC */
+ int spdif_rx_clk; /* rx clk mux select in SPDIF_REG_SRPC */
+ int (*spdif_clk_set_rate) (struct clk *clk, unsigned long rate);
struct clk *spdif_clk;
struct clk *spdif_core_clk;
struct clk *spdif_audio_clk;